#!/usr/bin/env sh
# Licensed Materials - Property of IBM
#
# (C) Copyright IBM Corp. 2003, 2011 All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplicate or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.
# IBM_COPYRIGHT_END


# -----------------------------------------------------------------
# Licensed Materials - Property of IBM
# 5724-F75
# (C) Copyright IBM Corp.  2003, 2004, 2009
# All Rights Reserved
# US Government Users Restricted Rights -Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
# -----------------------------------------------------------------

#/**
# * Creates PWD credentials - shell script
# *   
# */

#set -x
cmd_line=$@

#############################################################################
##     generate some basic help message                                    ##
#############################################################################

usage() {
        cat << EOF

Usage:  $0 {[option values] ...}

where options are:

	-help   --display this message
        -U      --username (REQUIERED)
        -P      --password (REQUIERED)
        -EP     --encrypted password (REQUIERED)
        -E      --enable secrets (OPTIONAL)
	-F	--fingerprint (OPTIONAL)

EOF
}

#############################################################################
##     parse the input arguments                                           ##
#############################################################################

for param in "$@"
do
        case $param in
                -U)
                        shift
                        username=$1
                        ;;
                -P)
                        shift
                        password=$1 
                        ;;
                -EP)
                        shift
                        epassword=$1 
                        ;;
                -E)
                        shift 
                        enable=$1
                        ;;
                -F)
                        shift 
                        fingerprint=$1
                        ;;
                -help)
                        usage
                        exit 0
                        ;;
                *)
                        shift
                        ;; 
        esac
done

#############################################################################
##     make sure we have all the required parameters                       ##
#############################################################################

if [ -z "$username" -o -z "$password" -o -z "$epassword" ]; then
        usage
        exit 1
fi

#*********************************************************#
#   Find the OS type running on the target                #
#*********************************************************#

case `uname` in
	Linux)
		awk_cmd=gawk
		os_type=linux
		;;
	CYGWIN_NT-5.0|CYGWIN_NT-5.1)
		awk_cmd=gawk
		os_type=windows
		;;
	SunOS)
		awk_cmd=nawk
		os_type=solaris
		;;
	*)
		echo "Unknown operating system"
		exit 1
		;;
esac

#*********************************************************#
#   Linux and Solaris user update                         #
#*********************************************************#

if [ "$os_type" = "linux" -o "$os_type" = "solaris" ]; then

#*********************************************************#
#   Create the user                                       #
#*********************************************************#

	if [ ! `cat /etc/passwd | $awk_cmd 'BEGIN { FS = ":" }; $0 ~ username { print $1 }' username=^$username:` ]; then
		useradd -m $username
	fi

#*********************************************************#
#   Update the password                                   #
#*********************************************************#

	cat /etc/shadow | $awk_cmd 'BEGIN { FS = ":" }; $0 ~ username \
		{print $1":"password":"$3":"$4":"$5":"$6":"$7":"$8":"}; $0 !~ \
		username {print $0}' username=^$username: password=$epassword > /etc/shadow.$$

	/bin/mv /etc/shadow.$$ /etc/shadow

	if [ $? -eq 0 ]; then
		echo "New user created"
		exit 0
	else
		echo "Error adding user"
		exit 1
	fi
fi

#*********************************************************#
#    Windows user update                                  #
#*********************************************************#

if [ "$os_type" = "windows" ]; then

	if [ ! `cat /etc/passwd | $awk_cmd 'BEGIN { FS = ":" }; $0 ~ username { print $1 }' username=^$username:` ]; then
		net user $username $password /add /expires:never
		mkpasswd -l > /etc/passwd.$$
		mv /etc/passwd.$$ /etc/passwd
        fi      

	if [ ! -d /home/$username ]; then
		mkdir /home/$username; chown $username /home/$username
	fi

	if [ $? -eq 0 ]; then
		echo "New user created"
		exit 0
	fi
fi

echo "Unknown operating system"
exit 1

