' Licensed Materials - Property of IBM
'
' (C) Copyright IBM Corp. 2010, 2011 All Rights Reserved
'
' US Government Users Restricted Rights - Use, duplicate or
' disclosure restricted by GSA ADP Schedule Contract with
' IBM Corp.
' IBM_COPYRIGHT_END

'  
' ============================================================================ 

' Define global variables
'
Dim FSO           ' FileSystemObject for reading directory structure
Dim Output        ' Output file for storing scanning results
Dim ScanRootPath  ' Path where scan begins
Dim OutputFile    ' Name of the output file
Dim RecursiveScan ' Indicates whether traverse through nested directories

' Check arguments
'
ArgsCount = WScript.Arguments.Count
Set NamedArgs = WScript.Arguments.Named

If ArgsCount = 3 And NamedArgs.Exists("p") And NamedArgs.Exists("o") And NamedArgs.Exists("r") Then
	ScanRootPath = NamedArgs.Item("p")
	OutputFile = NamedArgs.Item("o")
	RecursiveScan = NamedArgs.Item("r")
Else

	' Print script usage info
	'
	WScript.StdErr.WriteLine "Usage: scan_files.vbs /p:scanPath /o:outputFile /r:resursive[true|false]"
	WScript.Quit 1
End If

' Prepare output file
'
Set FSO = CreateObject("Scripting.FileSystemObject")
Set Output = FSO.CreateTextFile(OutputFile, True)

' Get string representing location of specified absolute Path relative to ScanRootPath
'
Function GetRelativePath(Path)
	Dim RelPos	
	RelPos = InStr(UCase(Path), UCase(ScanRootPath))
	
	' If Path begins in ScanRootPath, remove prefix 
	'
	If (RelPos = 1) Then
		GetRelativePath = Right (Path, len(Path) - len(ScanRootPath))
		
	' Otherwise absolute Path needs to be returned
	'
	Else
		GetRelativePath = Path
	End If	
End Function

' Get list of files and directories located in specified Path
'
Sub ListDir(Path)
	Dim Folders, Folder, Files, File
	
	' Ensure that Path exists
	'
	If (not FSO.FolderExists(Path)) Then
		WScript.StdErr.WriteLine "The " + scanRootPath + " directory does not exist"
		WScript.Quit 1
	End If
	
	' Get files and directories 
	'
	Set Folder = FSO.GetFolder(Path)	
	Set Files = Folder.Files
	Set Folders = Folder.SubFolders

	' Traverse through files, and put their relative location into output file
	'
	For Each File in Files
		Dim RelativePath, FullPath, RelPos
		RelativePath = GetRelativePath (Folder)
		FullPath = RelativePath + "\" + File.Name			
		
		' Ensure that file path does ot begin with '\'. This is to satisfy general assumption about output file format
		'
		If (Left(FullPath, 1) = "\") Then
			FullPath = Replace (FullPath, "\", "", 1, 1)
		End If
		
		Output.WriteLine(FullPath)
	Next

	' Traverse through subdirectories recirsively
	'
	If (RecursiveScan = "true") Then
		For Each Folder in Folders
			ListDir Folder
		Next
	End If
	
End Sub

' Start scannig in ScanRootPath
'
ListDir ScanRootPath